@@ -29,7 +29,7 @@
 #include "thparse.h"
 #include "thcsdata.h"
 #include "thexception.h"
-#include <proj_api.h>
+#include "thproj.h"
 #include "thdatabase.h"
 #include <map>
 #include <string>
@@ -108,6 +108,10 @@ const char * thcs_get_name(int cs)
   return csstr;
 }
 
+std::string thcs_get_params(int cs) {
+	return std::string(thcs_get_data(cs)->params);
+}
+
 const thcsdata * thcs_get_data(int cs) {
 	static thcsdata rv;
 	static char params[200];
@@ -120,10 +124,16 @@ const thcsdata * thcs_get_data(int cs) {
 	rv.prjspec = "";
 	rv.swap = false;
 	if (cs > TTCS_ESRI) {
+      if (esri_labels.find(cs - TTCS_ESRI) != esri_labels.end()) {
+        rv.prjname = esri_labels[cs - TTCS_ESRI];
+      }
 	  snprintf(params, sizeof(params), "+init=esri:%d", cs - TTCS_ESRI);
 		return &rv;
 	}
 	if (cs > TTCS_EPSG) {
+      if (epsg_labels.find(cs - TTCS_EPSG) != epsg_labels.end()) {
+        rv.prjname = epsg_labels[cs - TTCS_EPSG];
+      }
 	  snprintf(params, sizeof(params), "+init=epsg:%d", cs - TTCS_EPSG);
 		return &rv;
 	}
@@ -136,16 +146,14 @@ void thcs_add_cs(char * id, char * proj4id, size_t nargs, char ** args)
 {
   if (thcs_parse(id) != TTCS_UNKNOWN) ththrow(("cs already exists -- %s", id));
   if (!th_is_extkeyword(id)) ththrow(("invalid cs identifier -- %s", id));
-  projPJ P1;
-  if ((P1 = pj_init_plus(proj4id))==NULL) 
-    ththrow(("invalid proj4 identifier -- %s", proj4id));
-  pj_free(P1);
+  thcs_check(proj4id);
   thcsdata * pd = &(*thcs_custom_data.insert(thcs_custom_data.end(), thcsdata()));
   pd->prjspec = "";
   pd->params = thdb.strstore(proj4id);
-  pd->swap = false;
-  pd->output = true;
-  pd->dms = false;
+  pd->prjname = thdb.strstore(id);
+  pd->dms = thcs_islatlong(proj4id);
+  pd->swap = pd->dms;
+  pd->output = !pd->dms;
   thcs_custom_id--;
   thcs_custom_name2int[std::string(id)] = thcs_custom_id;
   thcs_custom_int2name[thcs_custom_id] = std::string(id);
